@@ -9,7 +9,7 @@ use CGI::Session::Driver;
 @CGI::Session::Driver::redis::ISA = ("CGI::Session::Driver");
 
 use vars qw($VERSION);
-our $VERSION = "0.5.1";
+our $VERSION = "0.2";
 
 
 =pod
@@ -35,15 +35,6 @@ CGI::Session::Driver::redis - CGI::Session driver for redis
 This backend stores session data in a persistent redis server, with
 the ability to specify an expiry time in seconds.
 
-=head1 REQUIREMENTS
-
-=over 4
-
-=item L<CGI::Session>
-
-=item L<Redis>
-
-=back
 
 =head1 DRIVER ARGUMENTS
 
@@ -53,7 +44,7 @@ The following options may be passed to the constructor:
 
 =item C<Expiry>
 
-Which is the time to expire the sessions, in seconds, on inactivity.
+Which is the time to expire the sessions, in seconds, in inactivity.
 Supplying a value of "0" equates to never expiring sessions.
 
 =item C<Prefix>
@@ -67,11 +58,32 @@ A Redis object which will be used to store the session data within.
 
 =back
 
+=head1 REQUIREMENTS
+
+=over 4
+
+=item L<CGI::Session>
+
+=item L<Redis>
+
+=back
+
+=head1 AUTHOR
+
+Steve Kemp <steve@steve.org.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2010 Steve Kemp <steve@steve.org.uk>.
+
+This library is free software. You can modify and or distribute it under
+the same terms as Perl itself.
+
+=cut
+
 
 =head1 METHODS
 
-Now follows documentation on the available methods.
-
 =cut
 
 
@@ -113,7 +125,7 @@ sub store
     # Get the prefix, and build a key
     #
     my $prefix = $self->{ 'Prefix' } || "session";
-    my $key = $prefix . ':' . $sid;
+    my $key    = $prefix . ':' . $sid;
 
     #
     # redis doesn't like to have whitespace in the keys.
@@ -125,19 +137,13 @@ sub store
     #
     $self->{ 'Redis' }->set( $key, $datastr );
 
-    #
-    # Add this key to the known list of sessions; required so that
-    # traverse can succeed.
-    #
-    $self->{ 'Redis' }->sadd( $prefix . ":members", $key );
-
     #
     #  Set the expiry time, in seconds, if present.
     #
-    my $expire = $self->{ 'Expire' } || 0;
+    my $expire = $self->{'Expire'} || 0;
     if ( $expire && $expire > 0 )
     {
-        $self->{ 'Redis' }->expire( $key, $expire );
+        $self->{ 'Redis' }->expire( "session:$sid", $expire );
     }
     return 1;
 }
@@ -159,14 +165,14 @@ sub retrieve
     # Get the prefix, and build a key
     #
     my $prefix = $self->{ 'Prefix' } || "session";
-    my $key = $prefix . ':' . $sid;
+    my $key    = $prefix . ':' . $sid;
 
     #
     # redis doesn't like to have whitespace in the keys.
     #
     $key =~ s/[ \t\r\n]//g;
 
-    my $rv = $self->{ 'Redis' }->get($key);
+    my $rv = $self->{ 'Redis' }->get( $key );
     return 0 unless defined($rv);
     return $rv;
 }
@@ -189,7 +195,7 @@ sub remove
     # Get the prefix, and build a key
     #
     my $prefix = $self->{ 'Prefix' } || "session";
-    my $key = $prefix . ':' . $sid;
+    my $key    = $prefix . ':' . $sid;
 
     #
     # redis doesn't like to have whitespace in the keys.
@@ -197,12 +203,7 @@ sub remove
     $key =~ s/[ \t\r\n]//g;
 
     # remove the data associated with the id
-    $self->{ 'Redis' }->del($key);
-
-    #
-    # Remove this key from the known list of sessions.
-    #
-    $self->{ 'Redis' }->srem( $prefix . ":members", $key );
+    $self->{ 'Redis' }->del( $key );
 
     return 1;
 }
@@ -218,45 +219,9 @@ sub teardown
 sub DESTROY
 {
     my $self = shift;
-
     # NOP
 }
 
-=head2 traverse
-
-Invoke the specified code reference on each active session.
-
-This is required to allow this driver to be used with the L<CGI::Session/find> method.
-
-=cut
-
-sub traverse
-{
-    my $self = shift;
-    my ($coderef) = @_;
-
-    unless ( $coderef && ref($coderef) && ( ref $coderef eq 'CODE' ) )
-    {
-        croak "traverse(): usage error";
-    }
-
-    my $prefix = $self->{ 'Prefix' } || "session";
-    my $key = $prefix . ':members';
-
-    #
-    # Redis doesn't like to have whitespace in the keys.
-    #
-    $key =~ s/[ \t\r\n]//g;
-
-    #
-    #  For each key invoke the callback.
-    #
-    foreach my $session ( $self->{ 'Redis' }->smembers($key) )
-    {
-        $coderef->($session);
-    }
-    return 1;
-}
 
 
 1;
@@ -285,19 +250,3 @@ L<Redis|Redis> - Redis interface library.
 =back
 
 =cut
-
-
-
-=head1 AUTHOR
-
-Steve Kemp <steve@steve.org.uk>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2010-2014 Steve Kemp <steve@steve.org.uk>.
-
-This library is free software. You can modify and or distribute it under
-the same terms as Perl itself.
-
-=cut
-
